#
# spec file for package apache-commons-codec
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2010, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define base_name  codec
%define short_name commons-%{base_name}
Name:           apache-commons-codec
Version:        1.10
Release:        47.26
Summary:        Apache Commons Codec Package
License:        Apache-2.0
Group:          Development/Libraries/Java
Url:            http://commons.apache.org/codec/
Source0:        http://www.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source4:        MANIFEST.MF
# PATCH-FIX-OPENSUSE Avoid spurious timeout in BeiderMorse tests
Patch0:         timeout.patch
BuildRequires:  ant >= 1.7
BuildRequires:  ant-junit >= 1.7
BuildRequires:  javapackages-local
BuildRequires:  javapackages-tools
# FIXME: mozilla-nss is necessary in order to use crypto, which is tested via junit tests
#        this should be a dependency of openjdk itself
BuildRequires:  junit
BuildRequires:  mozilla-nss
Requires:       java >= 1.6.0
Provides:       jakarta-%{short_name} = %{version}
Obsoletes:      jakarta-%{short_name} < %{version}
Provides:       %{short_name} = %{version}
Obsoletes:      %{short_name} < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Commons Codec is an attempt to provide definitive implementations of
commonly used encoders and decoders.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java
Requires:       java-javadoc
Provides:       jakarta-%{short_name}-javadoc = %{version}
Obsoletes:      jakarta-%{short_name}-javadoc < %{version}
Provides:       %{short_name}-javadoc = %{version}
Obsoletes:      %{short_name}-javadoc < %{version}

%description    javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{short_name}-%{version}-src
%patch0 -p1

#fixes eof encoding
sed -i 's/\r//' RELEASE-NOTES*.txt LICENSE.txt NOTICE.txt

%build
%if %with maven
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p ${MAVEN_REPO_LOCAL}
export MAVEN_OPTS="-Dmaven2.jpp.mode=true -Dmaven2.jpp.depmap.file=%{SOURCE2} -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -Dproject.build.directory=$(pwd)/target"
%{_bindir}/mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        install javadoc:javadoc
%else

export CLASSPATH=$(build-classpath junit)
ant -Dbuild.sysclasspath=first \
  -Dant.build.javac.source=1.6 -Dant.build.javac.target=1.6 \
  -Dconf.home=src/conf \
  -Dbuild.home=build \
  -Dsource.home=src/main/java \
  -Dtest.home=src/test/java \
  -Ddist.home=dist \
  -Dcomponent.title=%{short_name} \
  -Dcomponent.version=%{version} \
  -Dfinal.name=%{name}-%{version} \
  -Dextension.name=%{short_name} \
  test jar javadoc
%endif

%install
# jars
mkdir -p %{buildroot}%{_javadir}
%if %with maven
cp -p target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%else
jar umf %{SOURCE4} dist/%{name}-%{version}.jar
cp -p dist/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%endif
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}-%{version}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}-%{version}.jar
ln -s %{name}-%{version}.jar %{buildroot}%{_javadir}/jakarta-%{short_name}.jar

# Install pom file
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -p -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{short_name}.pom
%add_maven_depmap JPP-%{short_name}.pom %{short_name}.jar -a "%{short_name}:%{short_name}"

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}-%{version}
cp -pr dist/docs/api/* %{buildroot}%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/jakarta-%{short_name}-%{version}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/jakarta-%{short_name}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%files
%defattr(0644,root,root,0755)
%doc LICENSE.txt RELEASE-NOTES.txt
%{_javadir}/*.jar
%{_mavenpomdir}/*
%if %{defined _maven_repository}
%config(noreplace) %{_mavendepmapfragdir}/%{name}
%else
%{_datadir}/maven-metadata/%{name}.xml
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/*

%changelog
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Thu Sep  7 2017 fstrba@suse.com
- Build with java source and target versions 1.6
  * fixes build with jdk9
* Fri May 19 2017 tchvatal@suse.com
- Fix build with new javapackages-tools
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Fri Dec  5 2014 p.drouand@gmail.com
- Update to version 1.10
  New features:
  + Add Daitch-Mokotoff Soundex
    Issue: CODEC-192.
  + QuotedPrintableCodec does not support soft line break per the
    'quoted-printable' example on Wikipedia
    Issue: CODEC-121.
  + Make possible to provide padding byte to BaseNCodec in constructor
    Issue: CODEC-181.
  Fixed Bugs:
  + Added clarification to Javadoc of Base64 concerning the use of the
    urlSafe parameter
    Issue: CODEC-185.
  + Added clarification to the Javadoc of Base[32|64]OutputStream that it
    is mandatory to call close()
    Issue: CODEC-191.
  + Add support for HMAC Message Authentication Code (MAC) digests
    Issue: CODEC-188.
  + Beider Morse Phonetic Matching producing incorrect tokens
    Issue: CODEC-187.
  + NullPointerException in DoubleMetaPhone.isDoubleMetaphoneEqual when
    using empty strings
    Issue: CODEC-184.
  + Fix Javadoc 1.8.0 errors
    Issue: CODEC-180.
  + Fix Java 8 build Javadoc errors
    Issue: CODEC-189.
  Changes:
  + Deprecate Charsets Charset constants in favor of Java 7's
    java.nio.charset.StandardCharsets
    Issue: CODEC-178.
  + Update from commons-parent 34 to 35
    Issue: CODEC-190.
- Use javapackages-tools instead of java-devel
- Remove gpg_verify usage; let obs handle it
* Mon Jul  7 2014 tchvatal@suse.com
- Set the bytecode properly on sle11
* Mon Jul  7 2014 tchvatal@suse.com
- Depend on junit not junit4.
* Sun Jun 22 2014 schwab@suse.de
- timeout.patch: avoid spurious timeout in BeiderMorse tests
* Thu May 15 2014 darin@darins.net
- disable bytecode check on sle_11
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Mon Aug 26 2013 mvyskocil@suse.com
- update to 1.8
  * Add DigestUtils.updateDigest(MessageDigest, InputStream). Thanks to Daniel Cassidy.
  * Add JUnit to test our decode with pad character in the middle.
  * Add Match Rating Approach (MRA) phonetic algorithm encoder. Thanks to crice.
  * ColognePhonetic encoder unnecessarily creates many char arrays on every loop run. Thanks to leo141.
  * Base64.encodeBase64URLSafeString doesn't add padding characters at the end.
- temporary add mozilla-nss to BR: to pass tests
- drop unecessary source files
- add signature verification
- use newer add_maven_depmap
- fix source urls
* Mon Apr  2 2012 mvyskocil@suse.cz
- add junit4 to fix a build fail
* Tue Feb 28 2012 mvyskocil@suse.cz
- update to 1.6, sync with Fedora
* Fri Sep 22 2006 skh@suse.de
- don't use icecream
- use target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 dbornkessel@suse.de
- Current version 1.3 from JPackage.org
